package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.menu.domain.MenuRecipeDishes;
import com.bonus.canteen.core.menu.service.IMenuRecipeDishesService;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 菜品计划菜品关联Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "菜品计划菜品关联接口")
@RestController
@RequestMapping("/menu_recipe_dishes")
public class MenuRecipeDishesController extends BaseController {
    @Autowired
    private IMenuRecipeDishesService menuRecipeDishesService;

    /**
     * 查询菜品计划菜品关联列表
     */
    @ApiOperation(value = "查询菜品计划菜品关联列表")
    //@RequiresPermissions("menu:dishes:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuRecipeDishes menuRecipeDishes) {
        startPage();
        List<MenuRecipeDishes> list = menuRecipeDishesService.selectMenuRecipeDishesList(menuRecipeDishes);
        return getDataTable(list);
    }

    /**
     * 导出菜品计划菜品关联列表
     */
    @ApiOperation(value = "导出菜品计划菜品关联列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:export")
    @SysLog(title = "菜品计划菜品关联", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出菜品计划菜品关联")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuRecipeDishes menuRecipeDishes) {
        List<MenuRecipeDishes> list = menuRecipeDishesService.selectMenuRecipeDishesList(menuRecipeDishes);
        ExcelUtil<MenuRecipeDishes> util = new ExcelUtil<MenuRecipeDishes>(MenuRecipeDishes.class);
        util.exportExcel(response, list, "菜品计划菜品关联数据");
    }

    /**
     * 获取菜品计划菜品关联详细信息
     */
    @ApiOperation(value = "获取菜品计划菜品关联详细信息")
    //@RequiresPermissions("menu:dishes:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(menuRecipeDishesService.selectMenuRecipeDishesById(id));
    }

    /**
     * 新增菜品计划菜品关联
     */
    @ApiOperation(value = "新增菜品计划菜品关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:add")
    @SysLog(title = "菜品计划菜品关联", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品计划菜品关联")
    @PostMapping
    public AjaxResult add(@RequestBody MenuRecipeDishes menuRecipeDishes) {
        try {
            return toAjax(menuRecipeDishesService.insertMenuRecipeDishes(menuRecipeDishes));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改菜品计划菜品关联
     */
    @ApiOperation(value = "修改菜品计划菜品关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:edit")
    @SysLog(title = "菜品计划菜品关联", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改菜品计划菜品关联")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuRecipeDishes menuRecipeDishes) {
        try {
            return toAjax(menuRecipeDishesService.updateMenuRecipeDishes(menuRecipeDishes));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除菜品计划菜品关联
     */
    @ApiOperation(value = "删除菜品计划菜品关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:remove")
    @SysLog(title = "菜品计划菜品关联", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品计划菜品关联")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(menuRecipeDishesService.deleteMenuRecipeDishesByIds(ids));
    }
}
